#include <iostream>
#include <vector>
using namespace std;

// +oo
#define INFTY 99999999

// Bunch of macros to save some writing.
#define ii   pair<int, int>
#define vi   vector<int>
#define vd   vector<double>
#define vii  vector<ii>
#define vvi  vector<vi>
#define vvd  vector<vd>
#define vvii vector<vii>


bool bellman_ford(vvii &G, int S)
{
	// Upper bounds on distances from starting
	// node S for all nodes.
	vi distances(G.size(), INFTY);

	// This is what we know.
	distances[S] = 0;

	// Relax all edges in the graph V - 1
	// number of times, where V is the number
	// of nodes in the graph.
	for (int i = 0; i < G.size() - 1; ++i)
	{
		for (int u = 0; u < G.size(); ++u)
		{
			for (vii::iterator e = G[u].begin(); e != G[u].end(); ++e)
			{
				int v = e->first;
				int w = e->second;

				if (distances[v] > distances[u] + w)
					distances[v] = distances[u] + w;

			}
		}
	}

	// Relax one more time to find out whether any distance
	// changes, which would indicate there is a negative
	// cycle reachable from the starting node S.
	for (int u = 0; u < G.size(); ++u)
	{
		for (vii::iterator e = G[u].begin(); e != G[u].end(); ++e)
		{
			int v = e->first;
			int w = e->second;

			if (distances[v] > distances[u] + w)
				return true;
		}
	}

	return false;
}

int main(void)
{
	int c, n, m, x, y, t;

	// Make cout and cin faster if you prefer
	// them over their C alternatives.
	ios::sync_with_stdio(false);

	cin >> c;

	while (c--)
	{
		// Read the graph size.
		cin >> n >> m;

		// Adjacency list representation
		// of the graph.
		vvii G(n);

		// Read the graph specification.
		for (int i = 0; i < m; ++i)
		{
			cin >> x >> y >> t;

			// Add edge from x to y .
			G[x].push_back(ii(y, t));
		}

		cout << (bellman_ford(G, 0) ? "possible" : "not possible") << endl;
	}
}